telethon-tgcrypto
=================

Module ``telethon-tgcrypto`` brings better performance to
`Telethon <https://github.com/LonamiWebs/Telethon>`__ lib.

Installation
~~~~~~~~~~~~

**N.B.** you must not have ``cryptg`` installed, because it interferes with
this module.

To install this module and patch your Telethon installation just run:

::

    pip install telethon-tgcrypto

Credits
~~~~~~~

-  `@painor <https://github.com/painor>`__ for making this module
-  `@andrew <https://github.com/kittyandrew>`__ for writing this readme
-  `@tulir <https://github.com/tulir>`__ for the basic implementation
-  `@lonami <https://github.com/lonami>`__ &
   `contributors <https://github.com/LonamiWebs/Telethon/graphs/contributors>`__
   for making `telethon <https://github.com/LonamiWebs/Telethon>`__
-  `unknown <https://github.com/explore>`__ `d <https://github.com/delivrance>`__\ `eveloper <https://github.com/explore>`__
   for the fast crypto module
